==> jc-1.4.0.tar.gz: polyglot/types/CompoundResolver.h <==
// public class polyglot.types.CompoundResolver

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8cdb15e7e62de4c7 polyglot_types_CompoundResolver

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_CompoundResolver_H_
#define _JC_polyglot_types_CompoundResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_Named$object;
struct _jc_polyglot_types_Resolver$object;

// Typedefs
typedef struct _jc_polyglot_types_CompoundResolver$sub_refs	_jc_polyglot_types_CompoundResolver$sub_refs;
typedef struct _jc_polyglot_types_CompoundResolver$sub_nonrefs	_jc_polyglot_types_CompoundResolver$sub_nonrefs;
typedef struct _jc_polyglot_types_CompoundResolver$refs	_jc_polyglot_types_CompoundResolver$refs;
typedef struct _jc_polyglot_types_CompoundResolver$nonrefs	_jc_polyglot_types_CompoundResolver$nonrefs;
typedef struct _jc_polyglot_types_CompoundResolver$object	_jc_polyglot_types_CompoundResolver$object;

typedef const struct _jc_polyglot_types_CompoundResolver$vmethods	_jc_polyglot_types_CompoundResolver$vmethods;
typedef const struct _jc_polyglot_types_CompoundResolver$vtable	_jc_polyglot_types_CompoundResolver$vtable;
typedef const struct _jc_polyglot_types_CompoundResolver$vtype	_jc_polyglot_types_CompoundResolver$vtype;

// Constructors
extern void _jc_polyglot_types_CompoundResolver$method$_init$759213eee60a0646(_jc_env *, struct _jc_polyglot_types_CompoundResolver$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_types_CompoundResolver$method$find$6acc62ea1c707b3c(_jc_env *, struct _jc_polyglot_types_CompoundResolver$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_types_CompoundResolver$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_types_CompoundResolver$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_CompoundResolver$method_info$find$6acc62ea1c707b3c;
extern _jc_method _jc_polyglot_types_CompoundResolver$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_types_CompoundResolver$vmethods {
	struct _jc_object	*(*find$6acc62ea1c707b3c)(_jc_env *, struct _jc_polyglot_types_CompoundResolver$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_types_CompoundResolver$object *);
};

// Vtable
struct _jc_polyglot_types_CompoundResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_CompoundResolver$vmethods	polyglot_types_CompoundResolver;
};

// Vtype
struct _jc_polyglot_types_CompoundResolver$vtype {
	_jc_type			type;
	_jc_polyglot_types_CompoundResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_CompoundResolver$sub_refs {
	struct _jc_object	*head;
	struct _jc_object	*tail;
};

// Reference instance fields (object)
struct _jc_polyglot_types_CompoundResolver$refs {
    _jc_polyglot_types_CompoundResolver$sub_refs	polyglot_types_CompoundResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_CompoundResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_CompoundResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_CompoundResolver$sub_nonrefs	polyglot_types_CompoundResolver;
};

// Object instance structure
struct _jc_polyglot_types_CompoundResolver$object {
	_jc_polyglot_types_CompoundResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_CompoundResolver$vtype	*vtype;
	_jc_polyglot_types_CompoundResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_CompoundResolver$vtype _jc_polyglot_types_CompoundResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_CompoundResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_CompoundResolver$class_object;

#endif	/* _JC_polyglot_types_CompoundResolver_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/CompoundResolver.h <==
// public class polyglot.types.CompoundResolver

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8cdb15e7e62de4c7 polyglot_types_CompoundResolver

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_CompoundResolver_H_
#define _JC_polyglot_types_CompoundResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_Named$object;
struct _jc_polyglot_types_Resolver$object;

// Typedefs
typedef struct _jc_polyglot_types_CompoundResolver$sub_refs	_jc_polyglot_types_CompoundResolver$sub_refs;
typedef struct _jc_polyglot_types_CompoundResolver$sub_nonrefs	_jc_polyglot_types_CompoundResolver$sub_nonrefs;
typedef struct _jc_polyglot_types_CompoundResolver$refs	_jc_polyglot_types_CompoundResolver$refs;
typedef struct _jc_polyglot_types_CompoundResolver$nonrefs	_jc_polyglot_types_CompoundResolver$nonrefs;
typedef struct _jc_polyglot_types_CompoundResolver$object	_jc_polyglot_types_CompoundResolver$object;

typedef const struct _jc_polyglot_types_CompoundResolver$vmethods	_jc_polyglot_types_CompoundResolver$vmethods;
typedef const struct _jc_polyglot_types_CompoundResolver$vtable	_jc_polyglot_types_CompoundResolver$vtable;
typedef const struct _jc_polyglot_types_CompoundResolver$vtype	_jc_polyglot_types_CompoundResolver$vtype;

// Constructors
extern void _jc_polyglot_types_CompoundResolver$method$_init$759213eee60a0646(_jc_env *, struct _jc_polyglot_types_CompoundResolver$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_types_CompoundResolver$method$find$6acc62ea1c707b3c(_jc_env *, struct _jc_polyglot_types_CompoundResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_types_CompoundResolver$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_types_CompoundResolver$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_CompoundResolver$method_info$find$6acc62ea1c707b3c;
extern _jc_method _jc_polyglot_types_CompoundResolver$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_types_CompoundResolver$vmethods {
	struct _jc_object	*(*find$6acc62ea1c707b3c)(_jc_env *, struct _jc_polyglot_types_CompoundResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_types_CompoundResolver$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_types_CompoundResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_CompoundResolver$vmethods	polyglot_types_CompoundResolver;
};

// Vtype
struct _jc_polyglot_types_CompoundResolver$vtype {
	_jc_type			type;
	_jc_polyglot_types_CompoundResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_CompoundResolver$sub_refs {
	struct _jc_object	*head;
	struct _jc_object	*tail;
};

// Reference instance fields (object)
struct _jc_polyglot_types_CompoundResolver$refs {
    _jc_polyglot_types_CompoundResolver$sub_refs	polyglot_types_CompoundResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_CompoundResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_CompoundResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_CompoundResolver$sub_nonrefs	polyglot_types_CompoundResolver;
};

// Object instance structure
struct _jc_polyglot_types_CompoundResolver$object {
	_jc_polyglot_types_CompoundResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_CompoundResolver$vtype	*vtype;
	_jc_polyglot_types_CompoundResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_CompoundResolver$vtype _jc_polyglot_types_CompoundResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_CompoundResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_CompoundResolver$class_object;

#endif	/* _JC_polyglot_types_CompoundResolver_H_ */
